Container
==========

Container represents abstract API for container managers. It is now implemented by :class:`conu.backend.docker.image.DockerContainer`

.. autoclass:: conu.apidefs.container.Container
   :members:
